@@ -3,12 +3,9 @@
 #' 'adj.check.order' checks that the Cosine, Hermite or simple polynomials are
 #' of the correct order.
 #'
-#'
-#' Only even functions are allowed as adjustment terms. Also Hermite
-#' polynomials must be of degree at least 4 and Cosine of order at least 3.
-#' Finally, also checks that order of the terms >1 for half-normal/hazard-rate,
-#' as per p.47 of Buckland et al (2001). If incorrect terms are supplied then
-#' an error is throw via \code{stop}.
+#' Only even functions are allowed as adjustment terms, per p.47 of Buckland et
+#' al (2001). If incorrect terms are supplied then an error is throw via
+#' \code{stop}.
 #'
 #' @param adj.series Adjustment series used
 #'   ('\code{cos}','\code{herm}','\code{poly}')
@@ -24,24 +21,27 @@
 #'   Robust Models. In: Distance Sampling, eds. S.T.Buckland, D.R.Anderson,
 #'   K.P. Burnham, J.L. Laake. Chapman & Hall.
 #' @keywords methods
-adj.check.order <- function(adj.series,adj.order,key){
+adj.check.order <- function(adj.series, adj.order, key){
 
-  if(adj.series == "poly"){
+  if(adj.series %in% "poly"){
     # If polynomial, check even in a very crude way
     if(any(as.integer(adj.order/2) != (adj.order/2))){
       stop("Odd polynomial adjustment terms selected")
     }
+    if(key != "unif" & any(adj.order < 4)){
+      stop("Polynomial adjustment terms of order < 4 selected")
+    }
 
   }else if(adj.series == "herm"){
     # If hermite, check even and greater than (or equal to) order 4
-    if(any(adj.order < 4)){
-      stop("Hermite polynomial adjustment terms of order < 4 selected")
-    }
-
     if(any(as.integer(adj.order/2) != (adj.order/2))){
       stop("Odd Hermite polynomial adjustment terms selected")
     }
 
+    if(key != "unif" & any(adj.order < 4)){
+      stop("Hermite polynomial adjustment terms of order < 4 selected")
+    }
+
   }
 
   adj.name <- switch(adj.series,
