@@ -69,6 +69,16 @@ gof.trial.fi <- function(model,breaks=NULL,nc=NULL){
   p.1 <- NA
   df.2 <- NA
   p.2 <- NA
+  
+  # Calculate the pooled chi-square
+  df.pool <- 2*nc-length(model$par)-1
+  
+  if(df.pool <= 0){
+    df.pool <- NA
+    p.pool <- NA
+  }else{
+    p.pool <- 1-pchisq(chisq.1+chisq.2, df.pool)
+  }
 
   return(list(chi1=list(observed=observed.count.1,
                         expected=expected.1,
@@ -81,7 +91,6 @@ gof.trial.fi <- function(model,breaks=NULL,nc=NULL){
                         p=p.2,
                         df=df.2),
               pooled.chi=list(chisq=chisq.1+chisq.2,
-                              df=2*nc-length(model$par)-1,
-                              p=1-pchisq(chisq.1+chisq.2,
-                                         2*nc-length(model$par)-1))))
+                              df=df.pool,
+                              p=p.pool)))
 }
